@@ -265,13 +265,17 @@ void ochDeleteAll(void)
 {
 	struct outchannel *pOch, *pOchDel;
 
-	pOch = loadConf->och.ochRoot;
+	pOch = runConf->och.ochRoot;
 	while(pOch != NULL) {
 		dbgprintf("Delete Outchannel: Name='%s'\n ", pOch->pszName == NULL? "NULL" : pOch->pszName);
 		pOchDel = pOch;
 		pOch = pOch->pNext;
 		if(pOchDel->pszName != NULL)
 			free(pOchDel->pszName);
+		if(pOchDel->pszFileTemplate != NULL)
+			free(pOchDel->pszFileTemplate);
+		if(pOchDel->cmdOnSizeLimit != NULL)
+			free(pOchDel->cmdOnSizeLimit);
 		free(pOchDel);
 	}
 }
@@ -280,11 +284,11 @@ void ochDeleteAll(void)
 /* Print the outchannel structure. This is more or less a
  * debug or test aid, but anyhow I think it's worth it...
  */
-void ochPrintList(void)
+void ochPrintList(rsconf_t *cnf)
 {
 	struct outchannel *pOch;
 
-	pOch = loadConf->och.ochRoot;
+	pOch = cnf->och.ochRoot;
 	while(pOch != NULL) {
 		dbgprintf("Outchannel: Name='%s'\n", pOch->pszName == NULL? "NULL" : pOch->pszName);
 		dbgprintf("\tFile Template: '%s'\n", pOch->pszFileTemplate == NULL ? "NULL" :
