@@ -43,6 +43,8 @@ struct modConfData_s {
 	ratelimit_t *ratelimiter;
 	int ratelimitInterval;
 	int ratelimitBurst;
+	ruleset_t *pBindRuleset;	/* ruleset to bind (use system default if unspecified) */
+	uchar *pszBindRuleset;
 };
 
 /* interface to "drivers"
