@@ -8,7 +8,7 @@ add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
 input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
 
-$AllowedSender TCP,127.0.0.1
+$AllowedSender TCP,127.0.0.1/16,[::1]
 template(name="outfmt" type="string" string="%msg:F,58:2%\n")
 :msg, contains, "msgnum:" action(type="omfile" template="outfmt"
 			         file=`echo $RSYSLOG_OUT_LOG`)
