@@ -1,8 +1,9 @@
 #!/bin/bash
 # added 2014-09-24 by Rgerhards
-
 # This file is part of the rsyslog project, released under ASL 2.0
 . ${srcdir:=.}/diag.sh init
+export NUMMESSAGES=100
+export QUEUE_EMPTY_CHECK_FUNC=wait_file_lines
 generate_conf
 add_conf '
 module(load="../plugins/imtcp/.libs/imtcp")
@@ -13,8 +14,8 @@ if $syslogfacility-text == "local7" then
     action(type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
 '
 startup
-tcpflood -m1000 -P 185
-shutdown_when_empty # shut down rsyslogd when done processing messages
-wait_shutdown       # and wait for it to terminate
-seq_check 0 999 
+tcpflood -m$NUMMESSAGES -P 185
+shutdown_when_empty
+wait_shutdown
+seq_check
 exit_test
