@@ -52,7 +52,7 @@ static volatile int bHadHUP = 0;
 static void
 hdlr_sighup(int sig)
 {
-	fprintf(stderr, "had hup, sig %d\n", sig);
+	fprintf(stderr, "inputfilegen: had hup, sig %d\n", sig);
 	bHadHUP = 1;
 }
 static void
@@ -95,6 +95,7 @@ int main(int argc, char* argv[])
 	int c, i;
 	long long nmsgs = DEFMSGS;
 	long long nmsgstart = 0;
+	int nfinishedidle = 0;
 	int nchars = NOEXTRADATA;
 	int errflg = 0;
 	long long filesize = -1;
@@ -102,11 +103,12 @@ int main(int argc, char* argv[])
 	const char *msgcntfile = NULL;
 	const char *outputfile = "-";
 	FILE *fh_output;
-	int sleep_ms = 0;
-	int sleep_msgs = 0; /* messages to xmit between sleeps (if configured) */
+	int sleep_ms = 0;		/* How long to sleep between message writes */
+	int sleep_msgs = 0;		/* messages to xmit between sleeps (if configured) */
+	int sleep_hubreopen_ms = 5;	/* Wait until new file is being reopened, logrotate may need some time */
 	int ctr = 0;
 
-	while((c=getopt(argc, argv, "m:M:i:d:s:f:S:B:")) != -1) {
+	while((c=getopt(argc, argv, "m:M:i:I:h:d:s:f:S:B:")) != -1) {
 		switch(c) {
 		case 'm':
 			nmsgs = atoi(optarg);
@@ -117,6 +119,9 @@ int main(int argc, char* argv[])
 		case 'i':
 			nmsgstart = atoi(optarg);
 			break;
+		case 'I':
+			nfinishedidle = atoi(optarg);
+			break;
 		case 'd':
 			nchars = atoi(optarg);
 			break;
@@ -129,6 +134,9 @@ int main(int argc, char* argv[])
 		case 'B':
 			sleep_msgs = atoi(optarg);
 			break;
+		case 'h':
+			sleep_hubreopen_ms = atoi(optarg);
+			break;
 		case 'f':
 			outputfile = optarg;
 			sighup_enable();
@@ -138,7 +146,7 @@ int main(int argc, char* argv[])
 			errflg++;
 			break;
 		case '?':
-			fprintf(stderr, "Unrecognized option: -%c\n", optopt);
+			fprintf(stderr, "inputfilegen: Unrecognized option: -%c\n", optopt);
 			errflg++;
 			break;
 		}
@@ -151,11 +159,11 @@ int main(int argc, char* argv[])
 	if(filesize != -1) {
 		const int linesize = (17 + nchars); /* 17 is std line size! */
 		nmsgs = filesize / linesize;
-		fprintf(stderr, "file size requested %lld, actual %lld with "
+		fprintf(stderr, "inputfilegen: file size requested %lld, actual %lld with "
 			"%lld lines, %lld bytes less\n",
 			filesize, nmsgs * linesize, nmsgs, filesize - nmsgs * linesize);
 		if(nmsgs > 100000000) {
-			fprintf(stderr, "number of lines exhaust 8-digit line numbers "
+			fprintf(stderr, "inputfilegen: number of lines exhaust 8-digit line numbers "
 				"which are standard inside the testbench.\n"
 				"Use -d switch to add extra data (e.g. -d111 for "
 				"128 byte lines or -d47 for 64 byte lines)\n");
@@ -185,14 +193,20 @@ int main(int argc, char* argv[])
 		extradata[nchars] = '\0';
 	}
 	for(i = nmsgstart; i < (nmsgs+nmsgstart); ++i) {
-		if(sleep_ms > 0 && ctr++ >= sleep_msgs) {
+		if(	sleep_ms > 0 &&
+			ctr++ >= sleep_msgs) {
 			msleep(sleep_ms);
 			ctr = 0;
 		}
 		if(bHadHUP) {
 			fclose(fh_output);
+			if(sleep_hubreopen_ms > 0) {
+				/* Extra Sleep so logrotate or whatever can take place */
+				msleep(sleep_hubreopen_ms);
+			}
 			fh_output = open_output(outputfile);
-			fprintf(stderr, "%s reopened\n", outputfile);
+			fprintf(stderr, "inputfilegen: %s reopened\n", outputfile);
+			fprintf(stderr, "inputfilegen: current message number %d\n", i);
 			bHadHUP = 0;
 		}
 		fprintf(fh_output, "msgnum:%8.8d:", i);
@@ -201,6 +215,20 @@ int main(int argc, char* argv[])
 		}
 		fprintf(fh_output, "\n");
 	}
+	if (nfinishedidle > 0) {
+		/* Keep process open for nfinishedidle ms */
+		for(int x = 0; x < nfinishedidle; ++x) {
+			if(bHadHUP) {
+				/* Create empty file */
+				fh_output = open_output(outputfile);
+				fclose(fh_output);
+				fprintf(stderr, "inputfilegen: last message number was %d\n", i);
+				bHadHUP = 0;
+			}
+			msleep(1);
+		}
+	}
+
 	free(extradata);
 	return 0;
 }
