@@ -3,12 +3,12 @@
 # This file is part of the rsyslog project, released under ASL 2.0
 echo =============================================================================================
 echo \[json_var_case.sh\]: test for referencing local and global variables properly in comparisons
-. $srcdir/diag.sh init
+. ${srcdir:=.}/diag.sh init
 generate_conf
 add_conf '
 module(load="../plugins/mmjsonparse/.libs/mmjsonparse")
 module(load="../plugins/imtcp/.libs/imtcp")
-input(type="imtcp" port="'$TCPFLOOD_PORT'")
+input(type="imtcp" port="0" listenPortFileName="'$RSYSLOG_DYNNAME'.tcpflood_port")
 
 # we must make sure the template contains references to the variables
 template(name="outfmt" type="string" string="json prop:%$!val%  local prop:%$.val%  global prop:%$/val%\n")
