@@ -2,8 +2,8 @@
 # Test for queue data persisting at shutdown. We use the actual driver
 # to carry out multiple tests with different queue modes
 # added 2009-05-27 by Rgerhards
-# This file is part of the rsyslog project, released  under GPLv3
-echo \[queue-persist.sh\]:
+# This file is part of the rsyslog project, released ASL 2.0
+. ${srcdir:=.}/diag.sh init
 . $srcdir/queue-persist-drvr.sh LinkedList
 . $srcdir/queue-persist-drvr.sh FixedArray
 # the disk test should not fail, however, the config is extreme and using
